Proven authentication mechanisms
-------

**Description:**

Whenever your application has the option for users to authenticate themselves
your method should be "proven" and secure in the sense of that: 

1. it should comply to some security stadards/guidelines
2. Before implementing authentication on a live enviroment it has to be pentested/audited by 
   professionals.

**Solution:**

There are some general guidelines in order to ensure your authentication mechanism
is a "proven" one in order to harden your application against attackers.
These guidelines are listed in the following knowledgebase item:

- Access control pattern
